'-----------------------------------------------------------------------
' <copyright file="BindableBase.vb" company="Microsoft Corporation">
'     Copyright (c) Doug Holland, Microsoft Corporation. All rights reserved.
' </copyright>
'-----------------------------------------------------------------------

Imports System.Windows.Input
Imports System.Threading
Imports System.Runtime.Serialization
Imports System.Runtime.CompilerServices
Imports System.ComponentModel

Namespace MsdnMagazine.HelloWorld.ViewModel
	''' <summary>
	''' Provides an implementation of the <see cref="I:INotifyPropertyChanged"/> interface to support databinding of the view model.
	''' </summary>
	<DataContract>
	Public MustInherit Class BindableBase
		Implements INotifyPropertyChanged

		''' <summary>
		''' The event handler for the <see cref="E:PropertyChanged"/> event.
        ''' </summary>
        Private Event pc As PropertyChangedEventHandler
        'Public Event pc As ProgressChangedEventHandler

        Public Custom Event PropertyChanged As PropertyChangedEventHandler Implements INotifyPropertyChanged.PropertyChanged
            AddHandler(ByVal value As PropertyChangedEventHandler)
                AddHandler Me.pc, value
            End AddHandler

            RemoveHandler(ByVal value As PropertyChangedEventHandler)
                RemoveHandler Me.pc, value
            End RemoveHandler
            RaiseEvent(ByVal sender As System.Object, ByVal e As System.ComponentModel.PropertyChangedEventArgs)
            End RaiseEvent
        End Event
		''' <summary>
		''' Occurs when a property changes.
		''' </summary>
		''' <param name="name">The name of the property.</param>
        Public Sub OnPropertyChanged(ByVal name As String)
            RaiseEvent PropertyChanged(Me, New System.ComponentModel.PropertyChangedEventArgs(name))
        End Sub

		''' <summary>
		''' Sets the specified property with a value and notifies listeners if that value is different than the previous value.
		''' </summary>
		''' <typeparam name="T">The type of the property.</typeparam>
		''' <param name="storage">A reference to a property with both get and set accessors.</param>
		''' <param name="value">The new value of the property.</param>
		''' <param name="name">A string that represents the property name.</param>
		''' <returns><c>true</c> if the value was changed, <c>false</c> otherwise.</returns>
        Protected Overridable Function SetProperty(Of T)(ByRef storage As T, ByVal value As T, <CallerMemberName> ByVal name As String) As Boolean
            ' determine if the current value of the property is equal to the new value, if so simply return false.
            If Object.Equals(storage, value) Then
                Return False
            End If
            storage = value
            ' raise the OnPropertyChanged event.
            Me.OnPropertyChanged(name)
            Return True
        End Function
	End Class
End Namespace
