'-----------------------------------------------------------------------
' <copyright file="HelloWorldViewModel.vb" company="Microsoft Corporation">
'     Copyright (c) Doug Holland, Microsoft Corporation. All rights reserved.
' </copyright>
'-----------------------------------------------------------------------

Imports System.Windows.Input

Namespace MsdnMagazine.HelloWorld.ViewModel
	''' <summary>
	''' Portable view model.
	''' </summary>
	Public NotInheritable Class HelloWorldViewModel
		Inherits BindableBase

		''' <summary>
		''' The message to be displayed by the messaging manager.
		''' </summary>
		Private message As String

		''' <summary>
		''' The title of the message to be displayed by the messaging manager.
		''' </summary>
		Private title As String

		''' <summary>
		''' The platform specific implementation of the <see cref="T:IMessagingManager"/> interface.
		''' </summary>
		Private manager As IMessagingManager

		''' <summary>
		''' Initializes a new instance of the <see cref="T:HelloWorldViewModel"/> class.
		''' </summary>
		''' <param name="manager">The platform specific implementation of the <see cref="T:IMessagingManager"/> interface.</param>
		Public Sub New(ByVal manager As IMessagingManager, ByVal message As String, ByVal title As String)
			Me.manager = manager

			Me.message = message

			Me.title = title

			Me.DisplayMessageCommand = New Command(AddressOf Me.DisplayMessage)
		End Sub

		' <summary>
		''' Gets the display message command.
		''' </summary>
		''' <value>The display message command.</value>
		Private privateDisplayMessageCommand As ICommand
		Public Property DisplayMessageCommand As ICommand
			Get
				Return privateDisplayMessageCommand
			End Get
			Private Set(ByVal value As ICommand)
				privateDisplayMessageCommand = value
			End Set
		End Property

		''' <summary>
		''' Displays the message using the platform specific implementation of the <see cref="T:IMessagingManager"/> interface.
		''' </summary>
		Private async Sub DisplayMessage()
			await Me.manager.ShowAsync(Me.message, Me.title, MessagingButtons.OK)
		End Sub
	End Class
End Namespace
