'-----------------------------------------------------------------------
' <copyright file="MessagingManager.vb" company="Microsoft Corporation">
'     Copyright (c) Doug Holland, Microsoft Corporation. All rights reserved.
' </copyright>
'-----------------------------------------------------------------------

Imports MsdnMagazine.HelloWorld.ViewModel
Imports System.Windows.Threading
Imports System.Windows
Imports System.Threading.Tasks

Namespace MsdnMagazine.HelloWorld.WindowsPhone
	''' <summary>
	''' Provides a Windows Phone implementation of the <see cref="T:Windows.GeoPhoto.ViewModel.IMessagingManager"/> interface.
	''' </summary>
	Friend Class MessagingManager
		Implements IMessagingManager

		''' <summary>
		''' Initializes a new instance of the <see cref="T:MessagingManager"/> class.
		''' </summary>
		

		''' <summary>
		''' Displays the specified message using platform specific user messaging capabilities.
		''' </summary>
		''' <param name="message">The message to be displayed to the user.</param>
		''' <param name="title">The title of the message.</param>
		''' <returns>A <see cref="T:Windows.GeoPhoto.ViewModel.MessagingResult"/> value representing the users response.</returns>
		Public async Function ShowAsync(ByVal message As String, ByVal title As String) As Task(Of MessagingResult) Implements IMessagingManager.ShowAsync
			Dim result As MessagingResult = await Me.ShowAsync(message, title, MessagingButtons.OK)

			Return result
		End Function

		''' <summary>
		''' Displays the specified message using platform specific user messaging capabilities.
		''' </summary>
		''' <param name="message">The message to be displayed to the user.</param>
		''' <param name="title">The title of the message.</param>
		''' <param name="buttons">The buttons to be displayed.</param>
		''' <returns>A <see cref="T:Windows.GeoPhoto.ViewModel.MessagingResult"/> value representing the users response.</returns>
		Public async Function ShowAsync(ByVal message As String, ByVal title As String, ByVal buttons As MessagingButtons) As Task(Of MessagingResult) Implements IMessagingManager.ShowAsync
			Dim result As MessageBoxResult = MessageBoxResult.None

            App.RootFrame.Dispatcher.BeginInvoke(Sub() result = MessageBox.Show(message, title, CType(buttons, MessageBoxButton)))

			Return CType(result, MessagingResult)
		End Function
	End Class
End Namespace
