'-----------------------------------------------------------------------
' <copyright file="MessagingManager.vb" company="Microsoft Corporation">
'     Copyright (c) Doug Holland, Microsoft Corporation. All rights reserved.
' </copyright>
'-----------------------------------------------------------------------

Imports MsdnMagazine.HelloWorld.ViewModel
Imports Windows.UI.Xaml.Controls
Imports Windows.UI.Xaml
Imports Windows.UI.Popups
Imports Windows.UI.Core
Imports System.Threading.Tasks
Imports System

Namespace MsdnMagazine.HelloWorld.WindowsStore
	''' <summary>
	''' Provides a Windows Store implementation of the <see cref="T:Windows.GeoPhoto.ViewModel.IMessagingManager"/> interface. 
	''' </summary>
	Friend Class MessagingManager
		Implements IMessagingManager

		''' <summary>
		''' Initializes a new instance of the <see cref="T:MessagingManager"/> class.
		''' </summary>
		Public Sub New()
		End Sub

		''' <summary>
		''' Displays the specified message using platform specific user messaging capabilities.
		''' </summary>
		''' <param name="message">The message to be displayed to the user.</param>
		''' <param name="title">The title of the message.</param>
		''' <returns>A <see cref="T:Windows.GeoPhoto.ViewModel.MessagingResult"/> value representing the users response.</returns>
		Public async Function ShowAsync(ByVal message As String, ByVal title As String) As Task(Of MessagingResult) Implements IMessagingManager.ShowAsync
			Dim result As MessagingResult = await Me.ShowAsync(message, title, MessagingButtons.OK)

			Return result
		End Function

		''' <summary>
		''' Displays the specified message using platform specific user messaging capabilities.
		''' </summary>
		''' <param name="message">The message to be displayed to the user.</param>
		''' <param name="title">The title of the message.</param>
		''' <param name="buttons">The buttons to be displayed.</param>
		''' <returns>A <see cref="T:Windows.GeoPhoto.ViewModel.MessagingResult"/> value representing the users response.</returns>
		Public async Function ShowAsync(ByVal message As String, ByVal title As String, ByVal buttons As MessagingButtons) As Task(Of MessagingResult) Implements IMessagingManager.ShowAsync
			Dim dialog As New MessageDialog(message, title)

			Dim result As MessagingResult = MessagingResult.None

			Select Case buttons
				Case MessagingButtons.OK
					dialog.Commands.Add(New UICommand("OK", New UICommandInvokedHandler(Function(o) result = MessagingResult.OK)))

				Case MessagingButtons.OKCancel
					dialog.Commands.Add(New UICommand("OK", New UICommandInvokedHandler(Function(o) result = MessagingResult.OK)))
					dialog.Commands.Add(New UICommand("Cancel", New UICommandInvokedHandler(Function(o) result = MessagingResult.Cancel)))

				Case MessagingButtons.YesNo
					dialog.Commands.Add(New UICommand("Yes", New UICommandInvokedHandler(Function(o) result = MessagingResult.Yes)))
					dialog.Commands.Add(New UICommand("No", New UICommandInvokedHandler(Function(o) result = MessagingResult.No)))

				Case Else
					Throw New NotSupportedException(String.Format("MessagingButtons.{0} is not supported.", buttons.ToString))
			End Select

			dialog.DefaultCommandIndex = 1

			await Window.Current.Dispatcher.RunAsync(CoreDispatcherPriority.Normal, async Sub() await dialog.ShowAsync)

			Return result
		End Function
	End Class
End Namespace
